@@ -12,7 +12,7 @@ from .chat_permissions import ChatPermissions
 from .chat_photo import ChatPhoto
 from .input_file import InputFile
 from ..utils import helper, markdown
-from ..utils.deprecated import deprecated, DeprecatedReadOnlyClassVar
+from ..utils.deprecated import deprecated, DeprecatedReadOnlyClassVar, removed_argument
 
 
 class Chat(base.TelegramObject):
@@ -30,12 +30,14 @@ class Chat(base.TelegramObject):
     all_members_are_administrators: base.Boolean = fields.Field()
     photo: ChatPhoto = fields.Field(base=ChatPhoto)
     bio: base.String = fields.Field()
+    has_private_forwards: base.Boolean = fields.Field()
     description: base.String = fields.Field()
     invite_link: base.String = fields.Field()
     pinned_message: 'Message' = fields.Field(base='Message')
     permissions: ChatPermissions = fields.Field(base=ChatPermissions)
     slow_mode_delay: base.Integer = fields.Field()
     message_auto_delete_time: base.Integer = fields.Field()
+    has_protected_content: base.Boolean = fields.Field()
     sticker_set_name: base.String = fields.Field()
     can_set_sticker_set: base.Boolean = fields.Field()
     linked_chat_id: base.Integer = fields.Field()
@@ -621,6 +623,27 @@ class Chat(base.TelegramObject):
             message_id=message_id,
         )
 
+    @removed_argument("until_date", "2.19")
+    async def ban_sender_chat(
+        self,
+        sender_chat_id: base.Integer,
+    ):
+        """Shortcut for banChatSenderChat method."""
+        return await self.bot.ban_chat_sender_chat(
+            chat_id=self.id,
+            sender_chat_id=sender_chat_id,
+        )
+
+    async def unban_sender_chat(
+        self,
+        sender_chat_id: base.Integer,
+    ):
+        """Shortcut for unbanChatSenderChat method."""
+        return await self.bot.unban_chat_sender_chat(
+            chat_id=self.id,
+            sender_chat_id=sender_chat_id,
+        )
+
     def __int__(self):
         return self.id
 
@@ -742,6 +765,7 @@ class ChatActions(helper.Helper):
     FIND_LOCATION: str = helper.Item()  # find_location
     RECORD_VIDEO_NOTE: str = helper.Item()  # record_video_note
     UPLOAD_VIDEO_NOTE: str = helper.Item()  # upload_video_note
+    CHOOSE_STICKER: str = helper.Item()  # choose_sticker
 
     @classmethod
     async def _do(cls, action: str, sleep=None):
@@ -882,3 +906,13 @@ class ChatActions(helper.Helper):
         :return:
         """
         await cls._do(cls.UPLOAD_VIDEO_NOTE, sleep)
+
+    @classmethod
+    async def choose_sticker(cls, sleep=None):
+        """
+        Do choose sticker
+
+        :param sleep: sleep timeout
+        :return:
+        """
+        await cls._do(cls.CHOOSE_STICKER, sleep)
