@@ -3,9 +3,7 @@ from . import base, fields
 
 class Dice(base.TelegramObject):
     """
-    This object represents a dice with random value from 1 to 6.
-    (Yes, we're aware of the “proper” singular of die.
-    But it's awkward, and we decided to help it change. One dice at a time!)
+    This object represents an animated emoji that displays a random value.
     
     https://core.telegram.org/bots/api#dice
     """
@@ -19,3 +17,4 @@ class DiceEmoji:
     BASKETBALL = '🏀'
     FOOTBALL = '⚽'
     SLOT_MACHINE = '🎰'
+    BOWLING = '🎳'
